@@ -27,9 +27,11 @@ cmap: str = "gray"):
     plt.savefig(my_stringIObytes, format=format)
     my_stringIObytes.seek(0)
     my_base64_jpgData = base64.b64encode(my_stringIObytes.read()).decode()
+    plt.close()
     return my_base64_jpgData
 
 def exit_handler():
+    logging.info('VSUI exit handler triggered')
     disconnect()
                     
 # https://stackoverflow.com/a/51981833
@@ -56,7 +58,7 @@ def safe_emit(event, data):
     except:
         logging.warning(f'timeout {timeout_count} / {timeout_target}')
         timeout_count += 1
-        if timeout_count == timeout_target:
+        if timeout_count >= timeout_target:
             logging.error(f'socketio timeout, exiting!')
             disconnect()
             sys.exit(1)
